@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2020 Google LLC
+# Copyright 2022 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -16,7 +16,7 @@
 from collections import OrderedDict
 import functools
 import re
-from typing import Dict, Optional, Sequence, Tuple, Type, Union
+from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union
 import pkg_resources
 
 from google.api_core.client_options import ClientOptions
@@ -204,26 +204,27 @@ class ApplicationsAsyncClient:
         self,
         request: Union[appengine.GetApplicationRequest, dict] = None,
         *,
+        name: str = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> application.Application:
         r"""Gets information about an application.
 
-        .. code-block::
+        .. code-block:: python
 
             from google.cloud import appengine_admin_v1
 
-            def sample_get_application():
+            async def sample_get_application():
                 # Create a client
-                client = appengine_admin_v1.ApplicationsClient()
+                client = appengine_admin_v1.ApplicationsAsyncClient()
 
                 # Initialize request argument(s)
                 request = appengine_admin_v1.GetApplicationRequest(
                 )
 
                 # Make the request
-                response = client.get_application(request=request)
+                response = await client.get_application(request=request)
 
                 # Handle the response
                 print(response)
@@ -232,6 +233,13 @@ class ApplicationsAsyncClient:
             request (Union[google.cloud.appengine_admin_v1.types.GetApplicationRequest, dict]):
                 The request object. Request message for
                 `Applications.GetApplication`.
+            name (:class:`str`):
+                Name of the Application resource to get. Example:
+                ``apps/myapp``.
+
+                This corresponds to the ``name`` field
+                on the ``request`` instance; if ``request`` is provided, this
+                should not be set.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -246,8 +254,22 @@ class ApplicationsAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
+        # Quick check: If we got a request object, we should *not* have
+        # gotten any keyword arguments that map to the request.
+        has_flattened_params = any([name])
+        if request is not None and has_flattened_params:
+            raise ValueError(
+                "If the `request` argument is set, then none of "
+                "the individual field arguments should be set."
+            )
+
         request = appengine.GetApplicationRequest(request)
 
+        # If we have keyword arguments corresponding to fields on the
+        # request, apply these.
+        if name is not None:
+            request.name = name
+
         # Wrap the RPC method; this adds retry and timeout information,
         # and friendly error handling.
         rpc = gapic_v1.method_async.wrap_method(
@@ -263,7 +285,12 @@ class ApplicationsAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -288,14 +315,13 @@ class ApplicationsAsyncClient:
         `Managing Projects, Applications, and
         Billing <https://cloud.google.com/appengine/docs/standard/python/console/>`__.
 
-
-        .. code-block::
+        .. code-block:: python
 
             from google.cloud import appengine_admin_v1
 
-            def sample_create_application():
+            async def sample_create_application():
                 # Create a client
-                client = appengine_admin_v1.ApplicationsClient()
+                client = appengine_admin_v1.ApplicationsAsyncClient()
 
                 # Initialize request argument(s)
                 request = appengine_admin_v1.CreateApplicationRequest(
@@ -306,7 +332,7 @@ class ApplicationsAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = operation.result()
+                response = await operation.result()
 
                 # Handle the response
                 print(response)
@@ -341,7 +367,12 @@ class ApplicationsAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation_async.from_gapic(
@@ -369,15 +400,16 @@ class ApplicationsAsyncClient:
            controlling user access to the application.
         -  ``default_cookie_expiration`` - Cookie expiration policy for
            the application.
+        -  ``iap`` - Identity-Aware Proxy properties for the
+           application.
 
-
-        .. code-block::
+        .. code-block:: python
 
             from google.cloud import appengine_admin_v1
 
-            def sample_update_application():
+            async def sample_update_application():
                 # Create a client
-                client = appengine_admin_v1.ApplicationsClient()
+                client = appengine_admin_v1.ApplicationsAsyncClient()
 
                 # Initialize request argument(s)
                 request = appengine_admin_v1.UpdateApplicationRequest(
@@ -388,7 +420,7 @@ class ApplicationsAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = operation.result()
+                response = await operation.result()
 
                 # Handle the response
                 print(response)
@@ -429,7 +461,12 @@ class ApplicationsAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation_async.from_gapic(
@@ -462,14 +499,13 @@ class ApplicationsAsyncClient:
         . If the deletion was recent, the numeric ID can be found in the
         Cloud Console Activity Log.
 
-
-        .. code-block::
+        .. code-block:: python
 
             from google.cloud import appengine_admin_v1
 
-            def sample_repair_application():
+            async def sample_repair_application():
                 # Create a client
-                client = appengine_admin_v1.ApplicationsClient()
+                client = appengine_admin_v1.ApplicationsAsyncClient()
 
                 # Initialize request argument(s)
                 request = appengine_admin_v1.RepairApplicationRequest(
@@ -480,7 +516,7 @@ class ApplicationsAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = operation.result()
+                response = await operation.result()
 
                 # Handle the response
                 print(response)
@@ -521,7 +557,12 @@ class ApplicationsAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation_async.from_gapic(
