@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2020 Google LLC
+# Copyright 2022 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -16,7 +16,7 @@
 from collections import OrderedDict
 import functools
 import re
-from typing import Dict, Optional, Sequence, Tuple, Type, Union
+from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union
 import pkg_resources
 
 from google.api_core.client_options import ClientOptions
@@ -219,14 +219,13 @@ class AuthorizedCertificatesAsyncClient:
         r"""Lists all SSL certificates the user is authorized to
         administer.
 
-
-        .. code-block::
+        .. code-block:: python
 
             from google.cloud import appengine_admin_v1
 
-            def sample_list_authorized_certificates():
+            async def sample_list_authorized_certificates():
                 # Create a client
-                client = appengine_admin_v1.AuthorizedCertificatesClient()
+                client = appengine_admin_v1.AuthorizedCertificatesAsyncClient()
 
                 # Initialize request argument(s)
                 request = appengine_admin_v1.ListAuthorizedCertificatesRequest(
@@ -236,7 +235,7 @@ class AuthorizedCertificatesAsyncClient:
                 page_result = client.list_authorized_certificates(request=request)
 
                 # Handle the response
-                for response in page_result:
+                async for response in page_result:
                     print(response)
 
         Args:
@@ -276,12 +275,20 @@ class AuthorizedCertificatesAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # This method is paged; wrap the response in a pager, which provides
         # an `__aiter__` convenience method.
         response = pagers.ListAuthorizedCertificatesAsyncPager(
-            method=rpc, request=request, response=response, metadata=metadata,
+            method=rpc,
+            request=request,
+            response=response,
+            metadata=metadata,
         )
 
         # Done; return the response.
@@ -297,20 +304,20 @@ class AuthorizedCertificatesAsyncClient:
     ) -> certificate.AuthorizedCertificate:
         r"""Gets the specified SSL certificate.
 
-        .. code-block::
+        .. code-block:: python
 
             from google.cloud import appengine_admin_v1
 
-            def sample_get_authorized_certificate():
+            async def sample_get_authorized_certificate():
                 # Create a client
-                client = appengine_admin_v1.AuthorizedCertificatesClient()
+                client = appengine_admin_v1.AuthorizedCertificatesAsyncClient()
 
                 # Initialize request argument(s)
                 request = appengine_admin_v1.GetAuthorizedCertificateRequest(
                 )
 
                 # Make the request
-                response = client.get_authorized_certificate(request=request)
+                response = await client.get_authorized_certificate(request=request)
 
                 # Handle the response
                 print(response)
@@ -352,7 +359,12 @@ class AuthorizedCertificatesAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -367,20 +379,20 @@ class AuthorizedCertificatesAsyncClient:
     ) -> certificate.AuthorizedCertificate:
         r"""Uploads the specified SSL certificate.
 
-        .. code-block::
+        .. code-block:: python
 
             from google.cloud import appengine_admin_v1
 
-            def sample_create_authorized_certificate():
+            async def sample_create_authorized_certificate():
                 # Create a client
-                client = appengine_admin_v1.AuthorizedCertificatesClient()
+                client = appengine_admin_v1.AuthorizedCertificatesAsyncClient()
 
                 # Initialize request argument(s)
                 request = appengine_admin_v1.CreateAuthorizedCertificateRequest(
                 )
 
                 # Make the request
-                response = client.create_authorized_certificate(request=request)
+                response = await client.create_authorized_certificate(request=request)
 
                 # Handle the response
                 print(response)
@@ -422,7 +434,12 @@ class AuthorizedCertificatesAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -442,21 +459,20 @@ class AuthorizedCertificatesAsyncClient:
         certificate. The certificate ``display_name`` may also be
         updated.
 
-
-        .. code-block::
+        .. code-block:: python
 
             from google.cloud import appengine_admin_v1
 
-            def sample_update_authorized_certificate():
+            async def sample_update_authorized_certificate():
                 # Create a client
-                client = appengine_admin_v1.AuthorizedCertificatesClient()
+                client = appengine_admin_v1.AuthorizedCertificatesAsyncClient()
 
                 # Initialize request argument(s)
                 request = appengine_admin_v1.UpdateAuthorizedCertificateRequest(
                 )
 
                 # Make the request
-                response = client.update_authorized_certificate(request=request)
+                response = await client.update_authorized_certificate(request=request)
 
                 # Handle the response
                 print(response)
@@ -498,7 +514,12 @@ class AuthorizedCertificatesAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -513,20 +534,20 @@ class AuthorizedCertificatesAsyncClient:
     ) -> None:
         r"""Deletes the specified SSL certificate.
 
-        .. code-block::
+        .. code-block:: python
 
             from google.cloud import appengine_admin_v1
 
-            def sample_delete_authorized_certificate():
+            async def sample_delete_authorized_certificate():
                 # Create a client
-                client = appengine_admin_v1.AuthorizedCertificatesClient()
+                client = appengine_admin_v1.AuthorizedCertificatesAsyncClient()
 
                 # Initialize request argument(s)
                 request = appengine_admin_v1.DeleteAuthorizedCertificateRequest(
                 )
 
                 # Make the request
-                client.delete_authorized_certificate(request=request)
+                await client.delete_authorized_certificate(request=request)
 
         Args:
             request (Union[google.cloud.appengine_admin_v1.types.DeleteAuthorizedCertificateRequest, dict]):
@@ -557,7 +578,10 @@ class AuthorizedCertificatesAsyncClient:
 
         # Send the request.
         await rpc(
-            request, retry=retry, timeout=timeout, metadata=metadata,
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
         )
 
     async def __aenter__(self):
