@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2020 Google LLC
+# Copyright 2022 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -16,7 +16,7 @@
 from collections import OrderedDict
 import functools
 import re
-from typing import Dict, Optional, Sequence, Tuple, Type, Union
+from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union
 import pkg_resources
 
 from google.api_core.client_options import ClientOptions
@@ -215,13 +215,13 @@ class DomainMappingsAsyncClient:
     ) -> pagers.ListDomainMappingsAsyncPager:
         r"""Lists the domain mappings on an application.
 
-        .. code-block::
+        .. code-block:: python
 
             from google.cloud import appengine_admin_v1
 
-            def sample_list_domain_mappings():
+            async def sample_list_domain_mappings():
                 # Create a client
-                client = appengine_admin_v1.DomainMappingsClient()
+                client = appengine_admin_v1.DomainMappingsAsyncClient()
 
                 # Initialize request argument(s)
                 request = appengine_admin_v1.ListDomainMappingsRequest(
@@ -231,7 +231,7 @@ class DomainMappingsAsyncClient:
                 page_result = client.list_domain_mappings(request=request)
 
                 # Handle the response
-                for response in page_result:
+                async for response in page_result:
                     print(response)
 
         Args:
@@ -270,12 +270,20 @@ class DomainMappingsAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # This method is paged; wrap the response in a pager, which provides
         # an `__aiter__` convenience method.
         response = pagers.ListDomainMappingsAsyncPager(
-            method=rpc, request=request, response=response, metadata=metadata,
+            method=rpc,
+            request=request,
+            response=response,
+            metadata=metadata,
         )
 
         # Done; return the response.
@@ -291,20 +299,20 @@ class DomainMappingsAsyncClient:
     ) -> domain_mapping.DomainMapping:
         r"""Gets the specified domain mapping.
 
-        .. code-block::
+        .. code-block:: python
 
             from google.cloud import appengine_admin_v1
 
-            def sample_get_domain_mapping():
+            async def sample_get_domain_mapping():
                 # Create a client
-                client = appengine_admin_v1.DomainMappingsClient()
+                client = appengine_admin_v1.DomainMappingsAsyncClient()
 
                 # Initialize request argument(s)
                 request = appengine_admin_v1.GetDomainMappingRequest(
                 )
 
                 # Make the request
-                response = client.get_domain_mapping(request=request)
+                response = await client.get_domain_mapping(request=request)
 
                 # Handle the response
                 print(response)
@@ -343,7 +351,12 @@ class DomainMappingsAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -361,14 +374,13 @@ class DomainMappingsAsyncClient:
         list of available authorized domains, see
         ```AuthorizedDomains.ListAuthorizedDomains`` <>`__.
 
-
-        .. code-block::
+        .. code-block:: python
 
             from google.cloud import appengine_admin_v1
 
-            def sample_create_domain_mapping():
+            async def sample_create_domain_mapping():
                 # Create a client
-                client = appengine_admin_v1.DomainMappingsClient()
+                client = appengine_admin_v1.DomainMappingsAsyncClient()
 
                 # Initialize request argument(s)
                 request = appengine_admin_v1.CreateDomainMappingRequest(
@@ -379,7 +391,7 @@ class DomainMappingsAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = operation.result()
+                response = await operation.result()
 
                 # Handle the response
                 print(response)
@@ -421,7 +433,12 @@ class DomainMappingsAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation_async.from_gapic(
@@ -448,14 +465,13 @@ class DomainMappingsAsyncClient:
         administer the associated domain in order to update a
         ``DomainMapping`` resource.
 
-
-        .. code-block::
+        .. code-block:: python
 
             from google.cloud import appengine_admin_v1
 
-            def sample_update_domain_mapping():
+            async def sample_update_domain_mapping():
                 # Create a client
-                client = appengine_admin_v1.DomainMappingsClient()
+                client = appengine_admin_v1.DomainMappingsAsyncClient()
 
                 # Initialize request argument(s)
                 request = appengine_admin_v1.UpdateDomainMappingRequest(
@@ -466,7 +482,7 @@ class DomainMappingsAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = operation.result()
+                response = await operation.result()
 
                 # Handle the response
                 print(response)
@@ -508,7 +524,12 @@ class DomainMappingsAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation_async.from_gapic(
@@ -533,14 +554,13 @@ class DomainMappingsAsyncClient:
         to administer the associated domain in order to delete a
         ``DomainMapping`` resource.
 
-
-        .. code-block::
+        .. code-block:: python
 
             from google.cloud import appengine_admin_v1
 
-            def sample_delete_domain_mapping():
+            async def sample_delete_domain_mapping():
                 # Create a client
-                client = appengine_admin_v1.DomainMappingsClient()
+                client = appengine_admin_v1.DomainMappingsAsyncClient()
 
                 # Initialize request argument(s)
                 request = appengine_admin_v1.DeleteDomainMappingRequest(
@@ -551,7 +571,7 @@ class DomainMappingsAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = operation.result()
+                response = await operation.result()
 
                 # Handle the response
                 print(response)
@@ -603,7 +623,12 @@ class DomainMappingsAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation_async.from_gapic(
