@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2020 Google LLC
+# Copyright 2022 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -16,7 +16,7 @@
 from collections import OrderedDict
 import functools
 import re
-from typing import Dict, Optional, Sequence, Tuple, Type, Union
+from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union
 import pkg_resources
 
 from google.api_core.client_options import ClientOptions
@@ -214,13 +214,13 @@ class FirewallAsyncClient:
     ) -> pagers.ListIngressRulesAsyncPager:
         r"""Lists the firewall rules of an application.
 
-        .. code-block::
+        .. code-block:: python
 
             from google.cloud import appengine_admin_v1
 
-            def sample_list_ingress_rules():
+            async def sample_list_ingress_rules():
                 # Create a client
-                client = appengine_admin_v1.FirewallClient()
+                client = appengine_admin_v1.FirewallAsyncClient()
 
                 # Initialize request argument(s)
                 request = appengine_admin_v1.ListIngressRulesRequest(
@@ -230,7 +230,7 @@ class FirewallAsyncClient:
                 page_result = client.list_ingress_rules(request=request)
 
                 # Handle the response
-                for response in page_result:
+                async for response in page_result:
                     print(response)
 
         Args:
@@ -269,12 +269,20 @@ class FirewallAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # This method is paged; wrap the response in a pager, which provides
         # an `__aiter__` convenience method.
         response = pagers.ListIngressRulesAsyncPager(
-            method=rpc, request=request, response=response, metadata=metadata,
+            method=rpc,
+            request=request,
+            response=response,
+            metadata=metadata,
         )
 
         # Done; return the response.
@@ -296,21 +304,20 @@ class FirewallAsyncClient:
         IP range, then an "allow all" rule is explicitly added to the
         end of the list.
 
-
-        .. code-block::
+        .. code-block:: python
 
             from google.cloud import appengine_admin_v1
 
-            def sample_batch_update_ingress_rules():
+            async def sample_batch_update_ingress_rules():
                 # Create a client
-                client = appengine_admin_v1.FirewallClient()
+                client = appengine_admin_v1.FirewallAsyncClient()
 
                 # Initialize request argument(s)
                 request = appengine_admin_v1.BatchUpdateIngressRulesRequest(
                 )
 
                 # Make the request
-                response = client.batch_update_ingress_rules(request=request)
+                response = await client.batch_update_ingress_rules(request=request)
 
                 # Handle the response
                 print(response)
@@ -347,7 +354,12 @@ class FirewallAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -362,20 +374,20 @@ class FirewallAsyncClient:
     ) -> firewall.FirewallRule:
         r"""Creates a firewall rule for the application.
 
-        .. code-block::
+        .. code-block:: python
 
             from google.cloud import appengine_admin_v1
 
-            def sample_create_ingress_rule():
+            async def sample_create_ingress_rule():
                 # Create a client
-                client = appengine_admin_v1.FirewallClient()
+                client = appengine_admin_v1.FirewallAsyncClient()
 
                 # Initialize request argument(s)
                 request = appengine_admin_v1.CreateIngressRuleRequest(
                 )
 
                 # Make the request
-                response = client.create_ingress_rule(request=request)
+                response = await client.create_ingress_rule(request=request)
 
                 # Handle the response
                 print(response)
@@ -416,7 +428,12 @@ class FirewallAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -431,20 +448,20 @@ class FirewallAsyncClient:
     ) -> firewall.FirewallRule:
         r"""Gets the specified firewall rule.
 
-        .. code-block::
+        .. code-block:: python
 
             from google.cloud import appengine_admin_v1
 
-            def sample_get_ingress_rule():
+            async def sample_get_ingress_rule():
                 # Create a client
-                client = appengine_admin_v1.FirewallClient()
+                client = appengine_admin_v1.FirewallAsyncClient()
 
                 # Initialize request argument(s)
                 request = appengine_admin_v1.GetIngressRuleRequest(
                 )
 
                 # Make the request
-                response = client.get_ingress_rule(request=request)
+                response = await client.get_ingress_rule(request=request)
 
                 # Handle the response
                 print(response)
@@ -485,7 +502,12 @@ class FirewallAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -500,20 +522,20 @@ class FirewallAsyncClient:
     ) -> firewall.FirewallRule:
         r"""Updates the specified firewall rule.
 
-        .. code-block::
+        .. code-block:: python
 
             from google.cloud import appengine_admin_v1
 
-            def sample_update_ingress_rule():
+            async def sample_update_ingress_rule():
                 # Create a client
-                client = appengine_admin_v1.FirewallClient()
+                client = appengine_admin_v1.FirewallAsyncClient()
 
                 # Initialize request argument(s)
                 request = appengine_admin_v1.UpdateIngressRuleRequest(
                 )
 
                 # Make the request
-                response = client.update_ingress_rule(request=request)
+                response = await client.update_ingress_rule(request=request)
 
                 # Handle the response
                 print(response)
@@ -554,7 +576,12 @@ class FirewallAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -569,20 +596,20 @@ class FirewallAsyncClient:
     ) -> None:
         r"""Deletes the specified firewall rule.
 
-        .. code-block::
+        .. code-block:: python
 
             from google.cloud import appengine_admin_v1
 
-            def sample_delete_ingress_rule():
+            async def sample_delete_ingress_rule():
                 # Create a client
-                client = appengine_admin_v1.FirewallClient()
+                client = appengine_admin_v1.FirewallAsyncClient()
 
                 # Initialize request argument(s)
                 request = appengine_admin_v1.DeleteIngressRuleRequest(
                 )
 
                 # Make the request
-                client.delete_ingress_rule(request=request)
+                await client.delete_ingress_rule(request=request)
 
         Args:
             request (Union[google.cloud.appengine_admin_v1.types.DeleteIngressRuleRequest, dict]):
@@ -613,7 +640,10 @@ class FirewallAsyncClient:
 
         # Send the request.
         await rpc(
-            request, retry=retry, timeout=timeout, metadata=metadata,
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
         )
 
     async def __aenter__(self):
