@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2020 Google LLC
+# Copyright 2022 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -16,7 +16,7 @@
 from collections import OrderedDict
 import functools
 import re
-from typing import Dict, Optional, Sequence, Tuple, Type, Union
+from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union
 import pkg_resources
 
 from google.api_core.client_options import ClientOptions
@@ -216,14 +216,13 @@ class InstancesAsyncClient:
         `Stackdriver Monitoring
         API <https://cloud.google.com/monitoring/api/ref_v3/rest/v3/projects.timeSeries/list>`__.
 
-
-        .. code-block::
+        .. code-block:: python
 
             from google.cloud import appengine_admin_v1
 
-            def sample_list_instances():
+            async def sample_list_instances():
                 # Create a client
-                client = appengine_admin_v1.InstancesClient()
+                client = appengine_admin_v1.InstancesAsyncClient()
 
                 # Initialize request argument(s)
                 request = appengine_admin_v1.ListInstancesRequest(
@@ -233,7 +232,7 @@ class InstancesAsyncClient:
                 page_result = client.list_instances(request=request)
 
                 # Handle the response
-                for response in page_result:
+                async for response in page_result:
                     print(response)
 
         Args:
@@ -272,12 +271,20 @@ class InstancesAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # This method is paged; wrap the response in a pager, which provides
         # an `__aiter__` convenience method.
         response = pagers.ListInstancesAsyncPager(
-            method=rpc, request=request, response=response, metadata=metadata,
+            method=rpc,
+            request=request,
+            response=response,
+            metadata=metadata,
         )
 
         # Done; return the response.
@@ -293,20 +300,20 @@ class InstancesAsyncClient:
     ) -> instance.Instance:
         r"""Gets instance information.
 
-        .. code-block::
+        .. code-block:: python
 
             from google.cloud import appengine_admin_v1
 
-            def sample_get_instance():
+            async def sample_get_instance():
                 # Create a client
-                client = appengine_admin_v1.InstancesClient()
+                client = appengine_admin_v1.InstancesAsyncClient()
 
                 # Initialize request argument(s)
                 request = appengine_admin_v1.GetInstanceRequest(
                 )
 
                 # Make the request
-                response = client.get_instance(request=request)
+                response = await client.get_instance(request=request)
 
                 # Handle the response
                 print(response)
@@ -346,7 +353,12 @@ class InstancesAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -375,14 +387,13 @@ class InstancesAsyncClient:
         ```apps.services.versions.patch`` <https://cloud.google.com/appengine/docs/admin-api/reference/rest/v1/apps.services.versions/patch>`__
         method.
 
-
-        .. code-block::
+        .. code-block:: python
 
             from google.cloud import appengine_admin_v1
 
-            def sample_delete_instance():
+            async def sample_delete_instance():
                 # Create a client
-                client = appengine_admin_v1.InstancesClient()
+                client = appengine_admin_v1.InstancesAsyncClient()
 
                 # Initialize request argument(s)
                 request = appengine_admin_v1.DeleteInstanceRequest(
@@ -393,7 +404,7 @@ class InstancesAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = operation.result()
+                response = await operation.result()
 
                 # Handle the response
                 print(response)
@@ -445,7 +456,12 @@ class InstancesAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation_async.from_gapic(
@@ -477,14 +493,13 @@ class InstancesAsyncClient:
         Only applicable for instances in App Engine flexible
         environment.
 
-
-        .. code-block::
+        .. code-block:: python
 
             from google.cloud import appengine_admin_v1
 
-            def sample_debug_instance():
+            async def sample_debug_instance():
                 # Create a client
-                client = appengine_admin_v1.InstancesClient()
+                client = appengine_admin_v1.InstancesAsyncClient()
 
                 # Initialize request argument(s)
                 request = appengine_admin_v1.DebugInstanceRequest(
@@ -495,7 +510,7 @@ class InstancesAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = operation.result()
+                response = await operation.result()
 
                 # Handle the response
                 print(response)
@@ -536,7 +551,12 @@ class InstancesAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation_async.from_gapic(
