@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2020 Google LLC
+# Copyright 2022 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -16,7 +16,7 @@
 from collections import OrderedDict
 import os
 import re
-from typing import Dict, Optional, Sequence, Tuple, Type, Union
+from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union
 import pkg_resources
 
 from google.api_core import client_options as client_options_lib
@@ -59,7 +59,10 @@ class InstancesClientMeta(type):
     _transport_registry["grpc"] = InstancesGrpcTransport
     _transport_registry["grpc_asyncio"] = InstancesGrpcAsyncIOTransport
 
-    def get_transport_class(cls, label: str = None,) -> Type[InstancesTransport]:
+    def get_transport_class(
+        cls,
+        label: str = None,
+    ) -> Type[InstancesTransport]:
         """Returns an appropriate transport class.
 
         Args:
@@ -164,10 +167,18 @@ class InstancesClient(metaclass=InstancesClientMeta):
         return self._transport
 
     @staticmethod
-    def instance_path(app: str, service: str, version: str, instance: str,) -> str:
+    def instance_path(
+        app: str,
+        service: str,
+        version: str,
+        instance: str,
+    ) -> str:
         """Returns a fully-qualified instance string."""
         return "apps/{app}/services/{service}/versions/{version}/instances/{instance}".format(
-            app=app, service=service, version=version, instance=instance,
+            app=app,
+            service=service,
+            version=version,
+            instance=instance,
         )
 
     @staticmethod
@@ -180,7 +191,9 @@ class InstancesClient(metaclass=InstancesClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_billing_account_path(billing_account: str,) -> str:
+    def common_billing_account_path(
+        billing_account: str,
+    ) -> str:
         """Returns a fully-qualified billing_account string."""
         return "billingAccounts/{billing_account}".format(
             billing_account=billing_account,
@@ -193,9 +206,13 @@ class InstancesClient(metaclass=InstancesClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_folder_path(folder: str,) -> str:
+    def common_folder_path(
+        folder: str,
+    ) -> str:
         """Returns a fully-qualified folder string."""
-        return "folders/{folder}".format(folder=folder,)
+        return "folders/{folder}".format(
+            folder=folder,
+        )
 
     @staticmethod
     def parse_common_folder_path(path: str) -> Dict[str, str]:
@@ -204,9 +221,13 @@ class InstancesClient(metaclass=InstancesClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_organization_path(organization: str,) -> str:
+    def common_organization_path(
+        organization: str,
+    ) -> str:
         """Returns a fully-qualified organization string."""
-        return "organizations/{organization}".format(organization=organization,)
+        return "organizations/{organization}".format(
+            organization=organization,
+        )
 
     @staticmethod
     def parse_common_organization_path(path: str) -> Dict[str, str]:
@@ -215,9 +236,13 @@ class InstancesClient(metaclass=InstancesClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_project_path(project: str,) -> str:
+    def common_project_path(
+        project: str,
+    ) -> str:
         """Returns a fully-qualified project string."""
-        return "projects/{project}".format(project=project,)
+        return "projects/{project}".format(
+            project=project,
+        )
 
     @staticmethod
     def parse_common_project_path(path: str) -> Dict[str, str]:
@@ -226,10 +251,14 @@ class InstancesClient(metaclass=InstancesClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_location_path(project: str, location: str,) -> str:
+    def common_location_path(
+        project: str,
+        location: str,
+    ) -> str:
         """Returns a fully-qualified location string."""
         return "projects/{project}/locations/{location}".format(
-            project=project, location=location,
+            project=project,
+            location=location,
         )
 
     @staticmethod
@@ -401,6 +430,7 @@ class InstancesClient(metaclass=InstancesClientMeta):
                 quota_project_id=client_options.quota_project_id,
                 client_info=client_info,
                 always_use_jwt_access=True,
+                api_audience=client_options.api_audience,
             )
 
     def list_instances(
@@ -417,9 +447,7 @@ class InstancesClient(metaclass=InstancesClientMeta):
         `Stackdriver Monitoring
         API <https://cloud.google.com/monitoring/api/ref_v3/rest/v3/projects.timeSeries/list>`__.
 
-
-
-        .. code-block::
+        .. code-block:: python
 
             from google.cloud import appengine_admin_v1
 
@@ -475,12 +503,20 @@ class InstancesClient(metaclass=InstancesClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # This method is paged; wrap the response in a pager, which provides
         # an `__iter__` convenience method.
         response = pagers.ListInstancesPager(
-            method=rpc, request=request, response=response, metadata=metadata,
+            method=rpc,
+            request=request,
+            response=response,
+            metadata=metadata,
         )
 
         # Done; return the response.
@@ -496,8 +532,7 @@ class InstancesClient(metaclass=InstancesClientMeta):
     ) -> instance.Instance:
         r"""Gets instance information.
 
-
-        .. code-block::
+        .. code-block:: python
 
             from google.cloud import appengine_admin_v1
 
@@ -551,7 +586,12 @@ class InstancesClient(metaclass=InstancesClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -580,9 +620,7 @@ class InstancesClient(metaclass=InstancesClientMeta):
         ```apps.services.versions.patch`` <https://cloud.google.com/appengine/docs/admin-api/reference/rest/v1/apps.services.versions/patch>`__
         method.
 
-
-
-        .. code-block::
+        .. code-block:: python
 
             from google.cloud import appengine_admin_v1
 
@@ -652,7 +690,12 @@ class InstancesClient(metaclass=InstancesClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = gac_operation.from_gapic(
@@ -684,9 +727,7 @@ class InstancesClient(metaclass=InstancesClientMeta):
         Only applicable for instances in App Engine flexible
         environment.
 
-
-
-        .. code-block::
+        .. code-block:: python
 
             from google.cloud import appengine_admin_v1
 
@@ -745,7 +786,12 @@ class InstancesClient(metaclass=InstancesClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = gac_operation.from_gapic(
