@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2020 Google LLC
+# Copyright 2022 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -16,7 +16,7 @@
 from collections import OrderedDict
 import functools
 import re
-from typing import Dict, Optional, Sequence, Tuple, Type, Union
+from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union
 import pkg_resources
 
 from google.api_core.client_options import ClientOptions
@@ -208,13 +208,13 @@ class ServicesAsyncClient:
     ) -> pagers.ListServicesAsyncPager:
         r"""Lists all the services in the application.
 
-        .. code-block::
+        .. code-block:: python
 
             from google.cloud import appengine_admin_v1
 
-            def sample_list_services():
+            async def sample_list_services():
                 # Create a client
-                client = appengine_admin_v1.ServicesClient()
+                client = appengine_admin_v1.ServicesAsyncClient()
 
                 # Initialize request argument(s)
                 request = appengine_admin_v1.ListServicesRequest(
@@ -224,7 +224,7 @@ class ServicesAsyncClient:
                 page_result = client.list_services(request=request)
 
                 # Handle the response
-                for response in page_result:
+                async for response in page_result:
                     print(response)
 
         Args:
@@ -263,12 +263,20 @@ class ServicesAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # This method is paged; wrap the response in a pager, which provides
         # an `__aiter__` convenience method.
         response = pagers.ListServicesAsyncPager(
-            method=rpc, request=request, response=response, metadata=metadata,
+            method=rpc,
+            request=request,
+            response=response,
+            metadata=metadata,
         )
 
         # Done; return the response.
@@ -285,21 +293,20 @@ class ServicesAsyncClient:
         r"""Gets the current configuration of the specified
         service.
 
-
-        .. code-block::
+        .. code-block:: python
 
             from google.cloud import appengine_admin_v1
 
-            def sample_get_service():
+            async def sample_get_service():
                 # Create a client
-                client = appengine_admin_v1.ServicesClient()
+                client = appengine_admin_v1.ServicesAsyncClient()
 
                 # Initialize request argument(s)
                 request = appengine_admin_v1.GetServiceRequest(
                 )
 
                 # Make the request
-                response = client.get_service(request=request)
+                response = await client.get_service(request=request)
 
                 # Handle the response
                 print(response)
@@ -348,7 +355,12 @@ class ServicesAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -363,13 +375,13 @@ class ServicesAsyncClient:
     ) -> operation_async.AsyncOperation:
         r"""Updates the configuration of the specified service.
 
-        .. code-block::
+        .. code-block:: python
 
             from google.cloud import appengine_admin_v1
 
-            def sample_update_service():
+            async def sample_update_service():
                 # Create a client
-                client = appengine_admin_v1.ServicesClient()
+                client = appengine_admin_v1.ServicesAsyncClient()
 
                 # Initialize request argument(s)
                 request = appengine_admin_v1.UpdateServiceRequest(
@@ -380,7 +392,7 @@ class ServicesAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = operation.result()
+                response = await operation.result()
 
                 # Handle the response
                 print(response)
@@ -428,7 +440,12 @@ class ServicesAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation_async.from_gapic(
@@ -452,14 +469,13 @@ class ServicesAsyncClient:
         r"""Deletes the specified service and all enclosed
         versions.
 
-
-        .. code-block::
+        .. code-block:: python
 
             from google.cloud import appengine_admin_v1
 
-            def sample_delete_service():
+            async def sample_delete_service():
                 # Create a client
-                client = appengine_admin_v1.ServicesClient()
+                client = appengine_admin_v1.ServicesAsyncClient()
 
                 # Initialize request argument(s)
                 request = appengine_admin_v1.DeleteServiceRequest(
@@ -470,7 +486,7 @@ class ServicesAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = operation.result()
+                response = await operation.result()
 
                 # Handle the response
                 print(response)
@@ -522,7 +538,12 @@ class ServicesAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation_async.from_gapic(
