@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2020 Google LLC
+# Copyright 2022 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -16,7 +16,7 @@
 from collections import OrderedDict
 import functools
 import re
-from typing import Dict, Optional, Sequence, Tuple, Type, Union
+from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union
 import pkg_resources
 
 from google.api_core.client_options import ClientOptions
@@ -211,13 +211,13 @@ class VersionsAsyncClient:
     ) -> pagers.ListVersionsAsyncPager:
         r"""Lists the versions of a service.
 
-        .. code-block::
+        .. code-block:: python
 
             from google.cloud import appengine_admin_v1
 
-            def sample_list_versions():
+            async def sample_list_versions():
                 # Create a client
-                client = appengine_admin_v1.VersionsClient()
+                client = appengine_admin_v1.VersionsAsyncClient()
 
                 # Initialize request argument(s)
                 request = appengine_admin_v1.ListVersionsRequest(
@@ -227,7 +227,7 @@ class VersionsAsyncClient:
                 page_result = client.list_versions(request=request)
 
                 # Handle the response
-                for response in page_result:
+                async for response in page_result:
                     print(response)
 
         Args:
@@ -266,12 +266,20 @@ class VersionsAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # This method is paged; wrap the response in a pager, which provides
         # an `__aiter__` convenience method.
         response = pagers.ListVersionsAsyncPager(
-            method=rpc, request=request, response=response, metadata=metadata,
+            method=rpc,
+            request=request,
+            response=response,
+            metadata=metadata,
         )
 
         # Done; return the response.
@@ -289,21 +297,20 @@ class VersionsAsyncClient:
         ``BASIC_VIEW`` will be returned. Specify the ``FULL_VIEW``
         parameter to get the full resource.
 
-
-        .. code-block::
+        .. code-block:: python
 
             from google.cloud import appengine_admin_v1
 
-            def sample_get_version():
+            async def sample_get_version():
                 # Create a client
-                client = appengine_admin_v1.VersionsClient()
+                client = appengine_admin_v1.VersionsAsyncClient()
 
                 # Initialize request argument(s)
                 request = appengine_admin_v1.GetVersionRequest(
                 )
 
                 # Make the request
-                response = client.get_version(request=request)
+                response = await client.get_version(request=request)
 
                 # Handle the response
                 print(response)
@@ -343,7 +350,12 @@ class VersionsAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -358,13 +370,13 @@ class VersionsAsyncClient:
     ) -> operation_async.AsyncOperation:
         r"""Deploys code and resource files to a new version.
 
-        .. code-block::
+        .. code-block:: python
 
             from google.cloud import appengine_admin_v1
 
-            def sample_create_version():
+            async def sample_create_version():
                 # Create a client
-                client = appengine_admin_v1.VersionsClient()
+                client = appengine_admin_v1.VersionsAsyncClient()
 
                 # Initialize request argument(s)
                 request = appengine_admin_v1.CreateVersionRequest(
@@ -375,7 +387,7 @@ class VersionsAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = operation.result()
+                response = await operation.result()
 
                 # Handle the response
                 print(response)
@@ -416,7 +428,12 @@ class VersionsAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation_async.from_gapic(
@@ -474,14 +491,13 @@ class VersionsAsyncClient:
 
         -  ```manual_scaling.instances`` <https://cloud.google.com/appengine/docs/admin-api/reference/rest/v1/apps.services.versions#manualscaling>`__
 
-
-        .. code-block::
+        .. code-block:: python
 
             from google.cloud import appengine_admin_v1
 
-            def sample_update_version():
+            async def sample_update_version():
                 # Create a client
-                client = appengine_admin_v1.VersionsClient()
+                client = appengine_admin_v1.VersionsAsyncClient()
 
                 # Initialize request argument(s)
                 request = appengine_admin_v1.UpdateVersionRequest(
@@ -492,7 +508,7 @@ class VersionsAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = operation.result()
+                response = await operation.result()
 
                 # Handle the response
                 print(response)
@@ -533,7 +549,12 @@ class VersionsAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation_async.from_gapic(
@@ -556,13 +577,13 @@ class VersionsAsyncClient:
     ) -> operation_async.AsyncOperation:
         r"""Deletes an existing Version resource.
 
-        .. code-block::
+        .. code-block:: python
 
             from google.cloud import appengine_admin_v1
 
-            def sample_delete_version():
+            async def sample_delete_version():
                 # Create a client
-                client = appengine_admin_v1.VersionsClient()
+                client = appengine_admin_v1.VersionsAsyncClient()
 
                 # Initialize request argument(s)
                 request = appengine_admin_v1.DeleteVersionRequest(
@@ -573,7 +594,7 @@ class VersionsAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = operation.result()
+                response = await operation.result()
 
                 # Handle the response
                 print(response)
@@ -625,7 +646,12 @@ class VersionsAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation_async.from_gapic(
