@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2020 Google LLC
+# Copyright 2022 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -16,7 +16,12 @@
 import proto  # type: ignore
 
 
-__protobuf__ = proto.module(package="google.appengine.v1", manifest={"FirewallRule",},)
+__protobuf__ = proto.module(
+    package="google.appengine.v1",
+    manifest={
+        "FirewallRule",
+    },
+)
 
 
 class FirewallRule(proto.Message):
@@ -60,10 +65,23 @@ class FirewallRule(proto.Message):
         ALLOW = 1
         DENY = 2
 
-    priority = proto.Field(proto.INT32, number=1,)
-    action = proto.Field(proto.ENUM, number=2, enum=Action,)
-    source_range = proto.Field(proto.STRING, number=3,)
-    description = proto.Field(proto.STRING, number=4,)
+    priority = proto.Field(
+        proto.INT32,
+        number=1,
+    )
+    action = proto.Field(
+        proto.ENUM,
+        number=2,
+        enum=Action,
+    )
+    source_range = proto.Field(
+        proto.STRING,
+        number=3,
+    )
+    description = proto.Field(
+        proto.STRING,
+        number=4,
+    )
 
 
 __all__ = tuple(sorted(__protobuf__.manifest))
