@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2020 Google LLC
+# Copyright 2022 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -14,7 +14,13 @@
 # limitations under the License.
 #
 import os
-import mock
+
+# try/except added for compatibility with python < 3.8
+try:
+    from unittest import mock
+    from unittest.mock import AsyncMock
+except ImportError:
+    import mock
 
 import grpc
 from grpc.experimental import aio
@@ -93,20 +99,26 @@ def test__get_default_mtls_endpoint():
 
 
 @pytest.mark.parametrize(
-    "client_class", [AuthorizedCertificatesClient, AuthorizedCertificatesAsyncClient,]
+    "client_class,transport_name",
+    [
+        (AuthorizedCertificatesClient, "grpc"),
+        (AuthorizedCertificatesAsyncClient, "grpc_asyncio"),
+    ],
 )
-def test_authorized_certificates_client_from_service_account_info(client_class):
+def test_authorized_certificates_client_from_service_account_info(
+    client_class, transport_name
+):
     creds = ga_credentials.AnonymousCredentials()
     with mock.patch.object(
         service_account.Credentials, "from_service_account_info"
     ) as factory:
         factory.return_value = creds
         info = {"valid": True}
-        client = client_class.from_service_account_info(info)
+        client = client_class.from_service_account_info(info, transport=transport_name)
         assert client.transport._credentials == creds
         assert isinstance(client, client_class)
 
-        assert client.transport._host == "appengine.googleapis.com:443"
+        assert client.transport._host == ("appengine.googleapis.com:443")
 
 
 @pytest.mark.parametrize(
@@ -135,23 +147,33 @@ def test_authorized_certificates_client_service_account_always_use_jwt(
 
 
 @pytest.mark.parametrize(
-    "client_class", [AuthorizedCertificatesClient, AuthorizedCertificatesAsyncClient,]
+    "client_class,transport_name",
+    [
+        (AuthorizedCertificatesClient, "grpc"),
+        (AuthorizedCertificatesAsyncClient, "grpc_asyncio"),
+    ],
 )
-def test_authorized_certificates_client_from_service_account_file(client_class):
+def test_authorized_certificates_client_from_service_account_file(
+    client_class, transport_name
+):
     creds = ga_credentials.AnonymousCredentials()
     with mock.patch.object(
         service_account.Credentials, "from_service_account_file"
     ) as factory:
         factory.return_value = creds
-        client = client_class.from_service_account_file("dummy/file/path.json")
+        client = client_class.from_service_account_file(
+            "dummy/file/path.json", transport=transport_name
+        )
         assert client.transport._credentials == creds
         assert isinstance(client, client_class)
 
-        client = client_class.from_service_account_json("dummy/file/path.json")
+        client = client_class.from_service_account_json(
+            "dummy/file/path.json", transport=transport_name
+        )
         assert client.transport._credentials == creds
         assert isinstance(client, client_class)
 
-        assert client.transport._host == "appengine.googleapis.com:443"
+        assert client.transport._host == ("appengine.googleapis.com:443")
 
 
 def test_authorized_certificates_client_get_transport_class():
@@ -218,6 +240,7 @@ def test_authorized_certificates_client_client_options(
             quota_project_id=None,
             client_info=transports.base.DEFAULT_CLIENT_INFO,
             always_use_jwt_access=True,
+            api_audience=None,
         )
 
     # Check the case api_endpoint is not provided and GOOGLE_API_USE_MTLS_ENDPOINT is
@@ -235,6 +258,7 @@ def test_authorized_certificates_client_client_options(
                 quota_project_id=None,
                 client_info=transports.base.DEFAULT_CLIENT_INFO,
                 always_use_jwt_access=True,
+                api_audience=None,
             )
 
     # Check the case api_endpoint is not provided and GOOGLE_API_USE_MTLS_ENDPOINT is
@@ -252,6 +276,7 @@ def test_authorized_certificates_client_client_options(
                 quota_project_id=None,
                 client_info=transports.base.DEFAULT_CLIENT_INFO,
                 always_use_jwt_access=True,
+                api_audience=None,
             )
 
     # Check the case api_endpoint is not provided and GOOGLE_API_USE_MTLS_ENDPOINT has
@@ -281,6 +306,25 @@ def test_authorized_certificates_client_client_options(
             quota_project_id="octopus",
             client_info=transports.base.DEFAULT_CLIENT_INFO,
             always_use_jwt_access=True,
+            api_audience=None,
+        )
+    # Check the case api_endpoint is provided
+    options = client_options.ClientOptions(
+        api_audience="https://language.googleapis.com"
+    )
+    with mock.patch.object(transport_class, "__init__") as patched:
+        patched.return_value = None
+        client = client_class(client_options=options, transport=transport_name)
+        patched.assert_called_once_with(
+            credentials=None,
+            credentials_file=None,
+            host=client.DEFAULT_ENDPOINT,
+            scopes=None,
+            client_cert_source_for_mtls=None,
+            quota_project_id=None,
+            client_info=transports.base.DEFAULT_CLIENT_INFO,
+            always_use_jwt_access=True,
+            api_audience="https://language.googleapis.com",
         )
 
 
@@ -358,6 +402,7 @@ def test_authorized_certificates_client_mtls_env_auto(
                 quota_project_id=None,
                 client_info=transports.base.DEFAULT_CLIENT_INFO,
                 always_use_jwt_access=True,
+                api_audience=None,
             )
 
     # Check the case ADC client cert is provided. Whether client cert is used depends on
@@ -392,6 +437,7 @@ def test_authorized_certificates_client_mtls_env_auto(
                         quota_project_id=None,
                         client_info=transports.base.DEFAULT_CLIENT_INFO,
                         always_use_jwt_access=True,
+                        api_audience=None,
                     )
 
     # Check the case client_cert_source and ADC client cert are not provided.
@@ -414,6 +460,7 @@ def test_authorized_certificates_client_mtls_env_auto(
                     quota_project_id=None,
                     client_info=transports.base.DEFAULT_CLIENT_INFO,
                     always_use_jwt_access=True,
+                    api_audience=None,
                 )
 
 
@@ -517,7 +564,9 @@ def test_authorized_certificates_client_client_options_scopes(
     client_class, transport_class, transport_name
 ):
     # Check the case scopes are provided.
-    options = client_options.ClientOptions(scopes=["1", "2"],)
+    options = client_options.ClientOptions(
+        scopes=["1", "2"],
+    )
     with mock.patch.object(transport_class, "__init__") as patched:
         patched.return_value = None
         client = client_class(client_options=options, transport=transport_name)
@@ -530,6 +579,7 @@ def test_authorized_certificates_client_client_options_scopes(
             quota_project_id=None,
             client_info=transports.base.DEFAULT_CLIENT_INFO,
             always_use_jwt_access=True,
+            api_audience=None,
         )
 
 
@@ -568,6 +618,7 @@ def test_authorized_certificates_client_client_options_credentials_file(
             quota_project_id=None,
             client_info=transports.base.DEFAULT_CLIENT_INFO,
             always_use_jwt_access=True,
+            api_audience=None,
         )
 
 
@@ -588,6 +639,7 @@ def test_authorized_certificates_client_client_options_from_dict():
             quota_project_id=None,
             client_info=transports.base.DEFAULT_CLIENT_INFO,
             always_use_jwt_access=True,
+            api_audience=None,
         )
 
 
@@ -626,6 +678,7 @@ def test_authorized_certificates_client_create_channel_credentials_file(
             quota_project_id=None,
             client_info=transports.base.DEFAULT_CLIENT_INFO,
             always_use_jwt_access=True,
+            api_audience=None,
         )
 
     # test that the credentials from file are saved and used as the credentials.
@@ -662,11 +715,16 @@ def test_authorized_certificates_client_create_channel_credentials_file(
 
 
 @pytest.mark.parametrize(
-    "request_type", [appengine.ListAuthorizedCertificatesRequest, dict,]
+    "request_type",
+    [
+        appengine.ListAuthorizedCertificatesRequest,
+        dict,
+    ],
 )
 def test_list_authorized_certificates(request_type, transport: str = "grpc"):
     client = AuthorizedCertificatesClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
@@ -697,7 +755,8 @@ def test_list_authorized_certificates_empty_call():
     # This test is a coverage failsafe to make sure that totally empty calls,
     # i.e. request == None and no flattened fields passed, work.
     client = AuthorizedCertificatesClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport="grpc",
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport="grpc",
     )
 
     # Mock the actual call within the gRPC stub, and fake the request.
@@ -716,7 +775,8 @@ async def test_list_authorized_certificates_async(
     request_type=appengine.ListAuthorizedCertificatesRequest,
 ):
     client = AuthorizedCertificatesAsyncClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
@@ -759,7 +819,7 @@ def test_list_authorized_certificates_field_headers():
     # a field header. Set these to a non-empty value.
     request = appengine.ListAuthorizedCertificatesRequest()
 
-    request.parent = "parent/value"
+    request.parent = "parent_value"
 
     # Mock the actual call within the gRPC stub, and fake the request.
     with mock.patch.object(
@@ -775,7 +835,10 @@ def test_list_authorized_certificates_field_headers():
 
     # Establish that the field header was sent.
     _, _, kw = call.mock_calls[0]
-    assert ("x-goog-request-params", "parent=parent/value",) in kw["metadata"]
+    assert (
+        "x-goog-request-params",
+        "parent=parent_value",
+    ) in kw["metadata"]
 
 
 @pytest.mark.asyncio
@@ -788,7 +851,7 @@ async def test_list_authorized_certificates_field_headers_async():
     # a field header. Set these to a non-empty value.
     request = appengine.ListAuthorizedCertificatesRequest()
 
-    request.parent = "parent/value"
+    request.parent = "parent_value"
 
     # Mock the actual call within the gRPC stub, and fake the request.
     with mock.patch.object(
@@ -806,12 +869,16 @@ async def test_list_authorized_certificates_field_headers_async():
 
     # Establish that the field header was sent.
     _, _, kw = call.mock_calls[0]
-    assert ("x-goog-request-params", "parent=parent/value",) in kw["metadata"]
+    assert (
+        "x-goog-request-params",
+        "parent=parent_value",
+    ) in kw["metadata"]
 
 
 def test_list_authorized_certificates_pager(transport_name: str = "grpc"):
     client = AuthorizedCertificatesClient(
-        credentials=ga_credentials.AnonymousCredentials, transport=transport_name,
+        credentials=ga_credentials.AnonymousCredentials,
+        transport=transport_name,
     )
 
     # Mock the actual call within the gRPC stub, and fake the request.
@@ -829,10 +896,13 @@ def test_list_authorized_certificates_pager(transport_name: str = "grpc"):
                 next_page_token="abc",
             ),
             appengine.ListAuthorizedCertificatesResponse(
-                certificates=[], next_page_token="def",
+                certificates=[],
+                next_page_token="def",
             ),
             appengine.ListAuthorizedCertificatesResponse(
-                certificates=[certificate.AuthorizedCertificate(),],
+                certificates=[
+                    certificate.AuthorizedCertificate(),
+                ],
                 next_page_token="ghi",
             ),
             appengine.ListAuthorizedCertificatesResponse(
@@ -852,14 +922,15 @@ def test_list_authorized_certificates_pager(transport_name: str = "grpc"):
 
         assert pager._metadata == metadata
 
-        results = [i for i in pager]
+        results = list(pager)
         assert len(results) == 6
         assert all(isinstance(i, certificate.AuthorizedCertificate) for i in results)
 
 
 def test_list_authorized_certificates_pages(transport_name: str = "grpc"):
     client = AuthorizedCertificatesClient(
-        credentials=ga_credentials.AnonymousCredentials, transport=transport_name,
+        credentials=ga_credentials.AnonymousCredentials,
+        transport=transport_name,
     )
 
     # Mock the actual call within the gRPC stub, and fake the request.
@@ -877,10 +948,13 @@ def test_list_authorized_certificates_pages(transport_name: str = "grpc"):
                 next_page_token="abc",
             ),
             appengine.ListAuthorizedCertificatesResponse(
-                certificates=[], next_page_token="def",
+                certificates=[],
+                next_page_token="def",
             ),
             appengine.ListAuthorizedCertificatesResponse(
-                certificates=[certificate.AuthorizedCertificate(),],
+                certificates=[
+                    certificate.AuthorizedCertificate(),
+                ],
                 next_page_token="ghi",
             ),
             appengine.ListAuthorizedCertificatesResponse(
@@ -919,10 +993,13 @@ async def test_list_authorized_certificates_async_pager():
                 next_page_token="abc",
             ),
             appengine.ListAuthorizedCertificatesResponse(
-                certificates=[], next_page_token="def",
+                certificates=[],
+                next_page_token="def",
             ),
             appengine.ListAuthorizedCertificatesResponse(
-                certificates=[certificate.AuthorizedCertificate(),],
+                certificates=[
+                    certificate.AuthorizedCertificate(),
+                ],
                 next_page_token="ghi",
             ),
             appengine.ListAuthorizedCertificatesResponse(
@@ -933,10 +1010,12 @@ async def test_list_authorized_certificates_async_pager():
             ),
             RuntimeError,
         )
-        async_pager = await client.list_authorized_certificates(request={},)
+        async_pager = await client.list_authorized_certificates(
+            request={},
+        )
         assert async_pager.next_page_token == "abc"
         responses = []
-        async for response in async_pager:
+        async for response in async_pager:  # pragma: no branch
             responses.append(response)
 
         assert len(responses) == 6
@@ -966,10 +1045,13 @@ async def test_list_authorized_certificates_async_pages():
                 next_page_token="abc",
             ),
             appengine.ListAuthorizedCertificatesResponse(
-                certificates=[], next_page_token="def",
+                certificates=[],
+                next_page_token="def",
             ),
             appengine.ListAuthorizedCertificatesResponse(
-                certificates=[certificate.AuthorizedCertificate(),],
+                certificates=[
+                    certificate.AuthorizedCertificate(),
+                ],
                 next_page_token="ghi",
             ),
             appengine.ListAuthorizedCertificatesResponse(
@@ -983,18 +1065,23 @@ async def test_list_authorized_certificates_async_pages():
         pages = []
         async for page_ in (
             await client.list_authorized_certificates(request={})
-        ).pages:
+        ).pages:  # pragma: no branch
             pages.append(page_)
         for page_, token in zip(pages, ["abc", "def", "ghi", ""]):
             assert page_.raw_page.next_page_token == token
 
 
 @pytest.mark.parametrize(
-    "request_type", [appengine.GetAuthorizedCertificateRequest, dict,]
+    "request_type",
+    [
+        appengine.GetAuthorizedCertificateRequest,
+        dict,
+    ],
 )
 def test_get_authorized_certificate(request_type, transport: str = "grpc"):
     client = AuthorizedCertificatesClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
@@ -1035,7 +1122,8 @@ def test_get_authorized_certificate_empty_call():
     # This test is a coverage failsafe to make sure that totally empty calls,
     # i.e. request == None and no flattened fields passed, work.
     client = AuthorizedCertificatesClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport="grpc",
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport="grpc",
     )
 
     # Mock the actual call within the gRPC stub, and fake the request.
@@ -1054,7 +1142,8 @@ async def test_get_authorized_certificate_async(
     request_type=appengine.GetAuthorizedCertificateRequest,
 ):
     client = AuthorizedCertificatesAsyncClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
@@ -1107,7 +1196,7 @@ def test_get_authorized_certificate_field_headers():
     # a field header. Set these to a non-empty value.
     request = appengine.GetAuthorizedCertificateRequest()
 
-    request.name = "name/value"
+    request.name = "name_value"
 
     # Mock the actual call within the gRPC stub, and fake the request.
     with mock.patch.object(
@@ -1123,7 +1212,10 @@ def test_get_authorized_certificate_field_headers():
 
     # Establish that the field header was sent.
     _, _, kw = call.mock_calls[0]
-    assert ("x-goog-request-params", "name=name/value",) in kw["metadata"]
+    assert (
+        "x-goog-request-params",
+        "name=name_value",
+    ) in kw["metadata"]
 
 
 @pytest.mark.asyncio
@@ -1136,7 +1228,7 @@ async def test_get_authorized_certificate_field_headers_async():
     # a field header. Set these to a non-empty value.
     request = appengine.GetAuthorizedCertificateRequest()
 
-    request.name = "name/value"
+    request.name = "name_value"
 
     # Mock the actual call within the gRPC stub, and fake the request.
     with mock.patch.object(
@@ -1154,15 +1246,23 @@ async def test_get_authorized_certificate_field_headers_async():
 
     # Establish that the field header was sent.
     _, _, kw = call.mock_calls[0]
-    assert ("x-goog-request-params", "name=name/value",) in kw["metadata"]
+    assert (
+        "x-goog-request-params",
+        "name=name_value",
+    ) in kw["metadata"]
 
 
 @pytest.mark.parametrize(
-    "request_type", [appengine.CreateAuthorizedCertificateRequest, dict,]
+    "request_type",
+    [
+        appengine.CreateAuthorizedCertificateRequest,
+        dict,
+    ],
 )
 def test_create_authorized_certificate(request_type, transport: str = "grpc"):
     client = AuthorizedCertificatesClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
@@ -1203,7 +1303,8 @@ def test_create_authorized_certificate_empty_call():
     # This test is a coverage failsafe to make sure that totally empty calls,
     # i.e. request == None and no flattened fields passed, work.
     client = AuthorizedCertificatesClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport="grpc",
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport="grpc",
     )
 
     # Mock the actual call within the gRPC stub, and fake the request.
@@ -1222,7 +1323,8 @@ async def test_create_authorized_certificate_async(
     request_type=appengine.CreateAuthorizedCertificateRequest,
 ):
     client = AuthorizedCertificatesAsyncClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
@@ -1275,7 +1377,7 @@ def test_create_authorized_certificate_field_headers():
     # a field header. Set these to a non-empty value.
     request = appengine.CreateAuthorizedCertificateRequest()
 
-    request.parent = "parent/value"
+    request.parent = "parent_value"
 
     # Mock the actual call within the gRPC stub, and fake the request.
     with mock.patch.object(
@@ -1291,7 +1393,10 @@ def test_create_authorized_certificate_field_headers():
 
     # Establish that the field header was sent.
     _, _, kw = call.mock_calls[0]
-    assert ("x-goog-request-params", "parent=parent/value",) in kw["metadata"]
+    assert (
+        "x-goog-request-params",
+        "parent=parent_value",
+    ) in kw["metadata"]
 
 
 @pytest.mark.asyncio
@@ -1304,7 +1409,7 @@ async def test_create_authorized_certificate_field_headers_async():
     # a field header. Set these to a non-empty value.
     request = appengine.CreateAuthorizedCertificateRequest()
 
-    request.parent = "parent/value"
+    request.parent = "parent_value"
 
     # Mock the actual call within the gRPC stub, and fake the request.
     with mock.patch.object(
@@ -1322,15 +1427,23 @@ async def test_create_authorized_certificate_field_headers_async():
 
     # Establish that the field header was sent.
     _, _, kw = call.mock_calls[0]
-    assert ("x-goog-request-params", "parent=parent/value",) in kw["metadata"]
+    assert (
+        "x-goog-request-params",
+        "parent=parent_value",
+    ) in kw["metadata"]
 
 
 @pytest.mark.parametrize(
-    "request_type", [appengine.UpdateAuthorizedCertificateRequest, dict,]
+    "request_type",
+    [
+        appengine.UpdateAuthorizedCertificateRequest,
+        dict,
+    ],
 )
 def test_update_authorized_certificate(request_type, transport: str = "grpc"):
     client = AuthorizedCertificatesClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
@@ -1371,7 +1484,8 @@ def test_update_authorized_certificate_empty_call():
     # This test is a coverage failsafe to make sure that totally empty calls,
     # i.e. request == None and no flattened fields passed, work.
     client = AuthorizedCertificatesClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport="grpc",
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport="grpc",
     )
 
     # Mock the actual call within the gRPC stub, and fake the request.
@@ -1390,7 +1504,8 @@ async def test_update_authorized_certificate_async(
     request_type=appengine.UpdateAuthorizedCertificateRequest,
 ):
     client = AuthorizedCertificatesAsyncClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
@@ -1443,7 +1558,7 @@ def test_update_authorized_certificate_field_headers():
     # a field header. Set these to a non-empty value.
     request = appengine.UpdateAuthorizedCertificateRequest()
 
-    request.name = "name/value"
+    request.name = "name_value"
 
     # Mock the actual call within the gRPC stub, and fake the request.
     with mock.patch.object(
@@ -1459,7 +1574,10 @@ def test_update_authorized_certificate_field_headers():
 
     # Establish that the field header was sent.
     _, _, kw = call.mock_calls[0]
-    assert ("x-goog-request-params", "name=name/value",) in kw["metadata"]
+    assert (
+        "x-goog-request-params",
+        "name=name_value",
+    ) in kw["metadata"]
 
 
 @pytest.mark.asyncio
@@ -1472,7 +1590,7 @@ async def test_update_authorized_certificate_field_headers_async():
     # a field header. Set these to a non-empty value.
     request = appengine.UpdateAuthorizedCertificateRequest()
 
-    request.name = "name/value"
+    request.name = "name_value"
 
     # Mock the actual call within the gRPC stub, and fake the request.
     with mock.patch.object(
@@ -1490,15 +1608,23 @@ async def test_update_authorized_certificate_field_headers_async():
 
     # Establish that the field header was sent.
     _, _, kw = call.mock_calls[0]
-    assert ("x-goog-request-params", "name=name/value",) in kw["metadata"]
+    assert (
+        "x-goog-request-params",
+        "name=name_value",
+    ) in kw["metadata"]
 
 
 @pytest.mark.parametrize(
-    "request_type", [appengine.DeleteAuthorizedCertificateRequest, dict,]
+    "request_type",
+    [
+        appengine.DeleteAuthorizedCertificateRequest,
+        dict,
+    ],
 )
 def test_delete_authorized_certificate(request_type, transport: str = "grpc"):
     client = AuthorizedCertificatesClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
@@ -1526,7 +1652,8 @@ def test_delete_authorized_certificate_empty_call():
     # This test is a coverage failsafe to make sure that totally empty calls,
     # i.e. request == None and no flattened fields passed, work.
     client = AuthorizedCertificatesClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport="grpc",
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport="grpc",
     )
 
     # Mock the actual call within the gRPC stub, and fake the request.
@@ -1545,7 +1672,8 @@ async def test_delete_authorized_certificate_async(
     request_type=appengine.DeleteAuthorizedCertificateRequest,
 ):
     client = AuthorizedCertificatesAsyncClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
@@ -1583,7 +1711,7 @@ def test_delete_authorized_certificate_field_headers():
     # a field header. Set these to a non-empty value.
     request = appengine.DeleteAuthorizedCertificateRequest()
 
-    request.name = "name/value"
+    request.name = "name_value"
 
     # Mock the actual call within the gRPC stub, and fake the request.
     with mock.patch.object(
@@ -1599,7 +1727,10 @@ def test_delete_authorized_certificate_field_headers():
 
     # Establish that the field header was sent.
     _, _, kw = call.mock_calls[0]
-    assert ("x-goog-request-params", "name=name/value",) in kw["metadata"]
+    assert (
+        "x-goog-request-params",
+        "name=name_value",
+    ) in kw["metadata"]
 
 
 @pytest.mark.asyncio
@@ -1612,7 +1743,7 @@ async def test_delete_authorized_certificate_field_headers_async():
     # a field header. Set these to a non-empty value.
     request = appengine.DeleteAuthorizedCertificateRequest()
 
-    request.name = "name/value"
+    request.name = "name_value"
 
     # Mock the actual call within the gRPC stub, and fake the request.
     with mock.patch.object(
@@ -1628,7 +1759,10 @@ async def test_delete_authorized_certificate_field_headers_async():
 
     # Establish that the field header was sent.
     _, _, kw = call.mock_calls[0]
-    assert ("x-goog-request-params", "name=name/value",) in kw["metadata"]
+    assert (
+        "x-goog-request-params",
+        "name=name_value",
+    ) in kw["metadata"]
 
 
 def test_credentials_transport_error():
@@ -1638,7 +1772,8 @@ def test_credentials_transport_error():
     )
     with pytest.raises(ValueError):
         client = AuthorizedCertificatesClient(
-            credentials=ga_credentials.AnonymousCredentials(), transport=transport,
+            credentials=ga_credentials.AnonymousCredentials(),
+            transport=transport,
         )
 
     # It is an error to provide a credentials file and a transport instance.
@@ -1659,7 +1794,8 @@ def test_credentials_transport_error():
     options.api_key = "api_key"
     with pytest.raises(ValueError):
         client = AuthorizedCertificatesClient(
-            client_options=options, transport=transport,
+            client_options=options,
+            transport=transport,
         )
 
     # It is an error to provide an api_key and a credential.
@@ -1676,7 +1812,8 @@ def test_credentials_transport_error():
     )
     with pytest.raises(ValueError):
         client = AuthorizedCertificatesClient(
-            client_options={"scopes": ["1", "2"]}, transport=transport,
+            client_options={"scopes": ["1", "2"]},
+            transport=transport,
         )
 
 
@@ -1719,12 +1856,28 @@ def test_transport_adc(transport_class):
         adc.assert_called_once()
 
 
+@pytest.mark.parametrize(
+    "transport_name",
+    [
+        "grpc",
+    ],
+)
+def test_transport_kind(transport_name):
+    transport = AuthorizedCertificatesClient.get_transport_class(transport_name)(
+        credentials=ga_credentials.AnonymousCredentials(),
+    )
+    assert transport.kind == transport_name
+
+
 def test_transport_grpc_default():
     # A client should use the gRPC transport by default.
     client = AuthorizedCertificatesClient(
         credentials=ga_credentials.AnonymousCredentials(),
     )
-    assert isinstance(client.transport, transports.AuthorizedCertificatesGrpcTransport,)
+    assert isinstance(
+        client.transport,
+        transports.AuthorizedCertificatesGrpcTransport,
+    )
 
 
 def test_authorized_certificates_base_transport_error():
@@ -1762,6 +1915,14 @@ def test_authorized_certificates_base_transport():
     with pytest.raises(NotImplementedError):
         transport.close()
 
+    # Catch all for all remaining methods and properties
+    remainder = [
+        "kind",
+    ]
+    for r in remainder:
+        with pytest.raises(NotImplementedError):
+            getattr(transport, r)()
+
 
 def test_authorized_certificates_base_transport_with_credentials_file():
     # Instantiate the base transport with a credentials file
@@ -1773,7 +1934,8 @@ def test_authorized_certificates_base_transport_with_credentials_file():
         Transport.return_value = None
         load_creds.return_value = (ga_credentials.AnonymousCredentials(), None)
         transport = transports.AuthorizedCertificatesTransport(
-            credentials_file="credentials.json", quota_project_id="octopus",
+            credentials_file="credentials.json",
+            quota_project_id="octopus",
         )
         load_creds.assert_called_once_with(
             "credentials.json",
@@ -1838,6 +2000,28 @@ def test_authorized_certificates_transport_auth_adc(transport_class):
         )
 
 
+@pytest.mark.parametrize(
+    "transport_class",
+    [
+        transports.AuthorizedCertificatesGrpcTransport,
+        transports.AuthorizedCertificatesGrpcAsyncIOTransport,
+    ],
+)
+def test_authorized_certificates_transport_auth_gdch_credentials(transport_class):
+    host = "https://language.com"
+    api_audience_tests = [None, "https://language2.com"]
+    api_audience_expect = [host, "https://language2.com"]
+    for t, e in zip(api_audience_tests, api_audience_expect):
+        with mock.patch.object(google.auth, "default", autospec=True) as adc:
+            gdch_mock = mock.MagicMock()
+            type(gdch_mock).with_gdch_audience = mock.PropertyMock(
+                return_value=gdch_mock
+            )
+            adc.return_value = (gdch_mock, None)
+            transport_class(host=host, api_audience=t)
+            gdch_mock.with_gdch_audience.assert_called_once_with(e)
+
+
 @pytest.mark.parametrize(
     "transport_class,grpc_helpers",
     [
@@ -1926,24 +2110,40 @@ def test_authorized_certificates_grpc_transport_client_cert_source_for_mtls(
             )
 
 
-def test_authorized_certificates_host_no_port():
+@pytest.mark.parametrize(
+    "transport_name",
+    [
+        "grpc",
+        "grpc_asyncio",
+    ],
+)
+def test_authorized_certificates_host_no_port(transport_name):
     client = AuthorizedCertificatesClient(
         credentials=ga_credentials.AnonymousCredentials(),
         client_options=client_options.ClientOptions(
             api_endpoint="appengine.googleapis.com"
         ),
+        transport=transport_name,
     )
-    assert client.transport._host == "appengine.googleapis.com:443"
+    assert client.transport._host == ("appengine.googleapis.com:443")
 
 
-def test_authorized_certificates_host_with_port():
+@pytest.mark.parametrize(
+    "transport_name",
+    [
+        "grpc",
+        "grpc_asyncio",
+    ],
+)
+def test_authorized_certificates_host_with_port(transport_name):
     client = AuthorizedCertificatesClient(
         credentials=ga_credentials.AnonymousCredentials(),
         client_options=client_options.ClientOptions(
             api_endpoint="appengine.googleapis.com:8000"
         ),
+        transport=transport_name,
     )
-    assert client.transport._host == "appengine.googleapis.com:8000"
+    assert client.transport._host == ("appengine.googleapis.com:8000")
 
 
 def test_authorized_certificates_grpc_transport_channel():
@@ -1951,7 +2151,8 @@ def test_authorized_certificates_grpc_transport_channel():
 
     # Check that channel is used if provided.
     transport = transports.AuthorizedCertificatesGrpcTransport(
-        host="squid.clam.whelk", channel=channel,
+        host="squid.clam.whelk",
+        channel=channel,
     )
     assert transport.grpc_channel == channel
     assert transport._host == "squid.clam.whelk:443"
@@ -1963,7 +2164,8 @@ def test_authorized_certificates_grpc_asyncio_transport_channel():
 
     # Check that channel is used if provided.
     transport = transports.AuthorizedCertificatesGrpcAsyncIOTransport(
-        host="squid.clam.whelk", channel=channel,
+        host="squid.clam.whelk",
+        channel=channel,
     )
     assert transport.grpc_channel == channel
     assert transport._host == "squid.clam.whelk:443"
@@ -2092,7 +2294,9 @@ def test_parse_common_billing_account_path():
 
 def test_common_folder_path():
     folder = "whelk"
-    expected = "folders/{folder}".format(folder=folder,)
+    expected = "folders/{folder}".format(
+        folder=folder,
+    )
     actual = AuthorizedCertificatesClient.common_folder_path(folder)
     assert expected == actual
 
@@ -2110,7 +2314,9 @@ def test_parse_common_folder_path():
 
 def test_common_organization_path():
     organization = "oyster"
-    expected = "organizations/{organization}".format(organization=organization,)
+    expected = "organizations/{organization}".format(
+        organization=organization,
+    )
     actual = AuthorizedCertificatesClient.common_organization_path(organization)
     assert expected == actual
 
@@ -2128,7 +2334,9 @@ def test_parse_common_organization_path():
 
 def test_common_project_path():
     project = "cuttlefish"
-    expected = "projects/{project}".format(project=project,)
+    expected = "projects/{project}".format(
+        project=project,
+    )
     actual = AuthorizedCertificatesClient.common_project_path(project)
     assert expected == actual
 
@@ -2148,7 +2356,8 @@ def test_common_location_path():
     project = "winkle"
     location = "nautilus"
     expected = "projects/{project}/locations/{location}".format(
-        project=project, location=location,
+        project=project,
+        location=location,
     )
     actual = AuthorizedCertificatesClient.common_location_path(project, location)
     assert expected == actual
@@ -2173,7 +2382,8 @@ def test_client_with_default_client_info():
         transports.AuthorizedCertificatesTransport, "_prep_wrapped_messages"
     ) as prep:
         client = AuthorizedCertificatesClient(
-            credentials=ga_credentials.AnonymousCredentials(), client_info=client_info,
+            credentials=ga_credentials.AnonymousCredentials(),
+            client_info=client_info,
         )
         prep.assert_called_once_with(client_info)
 
@@ -2182,7 +2392,8 @@ def test_client_with_default_client_info():
     ) as prep:
         transport_class = AuthorizedCertificatesClient.get_transport_class()
         transport = transport_class(
-            credentials=ga_credentials.AnonymousCredentials(), client_info=client_info,
+            credentials=ga_credentials.AnonymousCredentials(),
+            client_info=client_info,
         )
         prep.assert_called_once_with(client_info)
 
@@ -2190,7 +2401,8 @@ def test_client_with_default_client_info():
 @pytest.mark.asyncio
 async def test_transport_close_async():
     client = AuthorizedCertificatesAsyncClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport="grpc_asyncio",
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport="grpc_asyncio",
     )
     with mock.patch.object(
         type(getattr(client.transport, "grpc_channel")), "close"
@@ -2263,4 +2475,5 @@ def test_api_key_credentials(client_class, transport_class):
                 quota_project_id=None,
                 client_info=transports.base.DEFAULT_CLIENT_INFO,
                 always_use_jwt_access=True,
+                api_audience=None,
             )
