@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2020 Google LLC
+# Copyright 2022 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -14,7 +14,13 @@
 # limitations under the License.
 #
 import os
-import mock
+
+# try/except added for compatibility with python < 3.8
+try:
+    from unittest import mock
+    from unittest.mock import AsyncMock
+except ImportError:
+    import mock
 
 import grpc
 from grpc.experimental import aio
@@ -91,20 +97,26 @@ def test__get_default_mtls_endpoint():
 
 
 @pytest.mark.parametrize(
-    "client_class", [AuthorizedDomainsClient, AuthorizedDomainsAsyncClient,]
+    "client_class,transport_name",
+    [
+        (AuthorizedDomainsClient, "grpc"),
+        (AuthorizedDomainsAsyncClient, "grpc_asyncio"),
+    ],
 )
-def test_authorized_domains_client_from_service_account_info(client_class):
+def test_authorized_domains_client_from_service_account_info(
+    client_class, transport_name
+):
     creds = ga_credentials.AnonymousCredentials()
     with mock.patch.object(
         service_account.Credentials, "from_service_account_info"
     ) as factory:
         factory.return_value = creds
         info = {"valid": True}
-        client = client_class.from_service_account_info(info)
+        client = client_class.from_service_account_info(info, transport=transport_name)
         assert client.transport._credentials == creds
         assert isinstance(client, client_class)
 
-        assert client.transport._host == "appengine.googleapis.com:443"
+        assert client.transport._host == ("appengine.googleapis.com:443")
 
 
 @pytest.mark.parametrize(
@@ -133,23 +145,33 @@ def test_authorized_domains_client_service_account_always_use_jwt(
 
 
 @pytest.mark.parametrize(
-    "client_class", [AuthorizedDomainsClient, AuthorizedDomainsAsyncClient,]
+    "client_class,transport_name",
+    [
+        (AuthorizedDomainsClient, "grpc"),
+        (AuthorizedDomainsAsyncClient, "grpc_asyncio"),
+    ],
 )
-def test_authorized_domains_client_from_service_account_file(client_class):
+def test_authorized_domains_client_from_service_account_file(
+    client_class, transport_name
+):
     creds = ga_credentials.AnonymousCredentials()
     with mock.patch.object(
         service_account.Credentials, "from_service_account_file"
     ) as factory:
         factory.return_value = creds
-        client = client_class.from_service_account_file("dummy/file/path.json")
+        client = client_class.from_service_account_file(
+            "dummy/file/path.json", transport=transport_name
+        )
         assert client.transport._credentials == creds
         assert isinstance(client, client_class)
 
-        client = client_class.from_service_account_json("dummy/file/path.json")
+        client = client_class.from_service_account_json(
+            "dummy/file/path.json", transport=transport_name
+        )
         assert client.transport._credentials == creds
         assert isinstance(client, client_class)
 
-        assert client.transport._host == "appengine.googleapis.com:443"
+        assert client.transport._host == ("appengine.googleapis.com:443")
 
 
 def test_authorized_domains_client_get_transport_class():
@@ -212,6 +234,7 @@ def test_authorized_domains_client_client_options(
             quota_project_id=None,
             client_info=transports.base.DEFAULT_CLIENT_INFO,
             always_use_jwt_access=True,
+            api_audience=None,
         )
 
     # Check the case api_endpoint is not provided and GOOGLE_API_USE_MTLS_ENDPOINT is
@@ -229,6 +252,7 @@ def test_authorized_domains_client_client_options(
                 quota_project_id=None,
                 client_info=transports.base.DEFAULT_CLIENT_INFO,
                 always_use_jwt_access=True,
+                api_audience=None,
             )
 
     # Check the case api_endpoint is not provided and GOOGLE_API_USE_MTLS_ENDPOINT is
@@ -246,6 +270,7 @@ def test_authorized_domains_client_client_options(
                 quota_project_id=None,
                 client_info=transports.base.DEFAULT_CLIENT_INFO,
                 always_use_jwt_access=True,
+                api_audience=None,
             )
 
     # Check the case api_endpoint is not provided and GOOGLE_API_USE_MTLS_ENDPOINT has
@@ -275,6 +300,25 @@ def test_authorized_domains_client_client_options(
             quota_project_id="octopus",
             client_info=transports.base.DEFAULT_CLIENT_INFO,
             always_use_jwt_access=True,
+            api_audience=None,
+        )
+    # Check the case api_endpoint is provided
+    options = client_options.ClientOptions(
+        api_audience="https://language.googleapis.com"
+    )
+    with mock.patch.object(transport_class, "__init__") as patched:
+        patched.return_value = None
+        client = client_class(client_options=options, transport=transport_name)
+        patched.assert_called_once_with(
+            credentials=None,
+            credentials_file=None,
+            host=client.DEFAULT_ENDPOINT,
+            scopes=None,
+            client_cert_source_for_mtls=None,
+            quota_project_id=None,
+            client_info=transports.base.DEFAULT_CLIENT_INFO,
+            always_use_jwt_access=True,
+            api_audience="https://language.googleapis.com",
         )
 
 
@@ -352,6 +396,7 @@ def test_authorized_domains_client_mtls_env_auto(
                 quota_project_id=None,
                 client_info=transports.base.DEFAULT_CLIENT_INFO,
                 always_use_jwt_access=True,
+                api_audience=None,
             )
 
     # Check the case ADC client cert is provided. Whether client cert is used depends on
@@ -386,6 +431,7 @@ def test_authorized_domains_client_mtls_env_auto(
                         quota_project_id=None,
                         client_info=transports.base.DEFAULT_CLIENT_INFO,
                         always_use_jwt_access=True,
+                        api_audience=None,
                     )
 
     # Check the case client_cert_source and ADC client cert are not provided.
@@ -408,6 +454,7 @@ def test_authorized_domains_client_mtls_env_auto(
                     quota_project_id=None,
                     client_info=transports.base.DEFAULT_CLIENT_INFO,
                     always_use_jwt_access=True,
+                    api_audience=None,
                 )
 
 
@@ -507,7 +554,9 @@ def test_authorized_domains_client_client_options_scopes(
     client_class, transport_class, transport_name
 ):
     # Check the case scopes are provided.
-    options = client_options.ClientOptions(scopes=["1", "2"],)
+    options = client_options.ClientOptions(
+        scopes=["1", "2"],
+    )
     with mock.patch.object(transport_class, "__init__") as patched:
         patched.return_value = None
         client = client_class(client_options=options, transport=transport_name)
@@ -520,6 +569,7 @@ def test_authorized_domains_client_client_options_scopes(
             quota_project_id=None,
             client_info=transports.base.DEFAULT_CLIENT_INFO,
             always_use_jwt_access=True,
+            api_audience=None,
         )
 
 
@@ -558,6 +608,7 @@ def test_authorized_domains_client_client_options_credentials_file(
             quota_project_id=None,
             client_info=transports.base.DEFAULT_CLIENT_INFO,
             always_use_jwt_access=True,
+            api_audience=None,
         )
 
 
@@ -578,6 +629,7 @@ def test_authorized_domains_client_client_options_from_dict():
             quota_project_id=None,
             client_info=transports.base.DEFAULT_CLIENT_INFO,
             always_use_jwt_access=True,
+            api_audience=None,
         )
 
 
@@ -616,6 +668,7 @@ def test_authorized_domains_client_create_channel_credentials_file(
             quota_project_id=None,
             client_info=transports.base.DEFAULT_CLIENT_INFO,
             always_use_jwt_access=True,
+            api_audience=None,
         )
 
     # test that the credentials from file are saved and used as the credentials.
@@ -652,11 +705,16 @@ def test_authorized_domains_client_create_channel_credentials_file(
 
 
 @pytest.mark.parametrize(
-    "request_type", [appengine.ListAuthorizedDomainsRequest, dict,]
+    "request_type",
+    [
+        appengine.ListAuthorizedDomainsRequest,
+        dict,
+    ],
 )
 def test_list_authorized_domains(request_type, transport: str = "grpc"):
     client = AuthorizedDomainsClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
@@ -687,7 +745,8 @@ def test_list_authorized_domains_empty_call():
     # This test is a coverage failsafe to make sure that totally empty calls,
     # i.e. request == None and no flattened fields passed, work.
     client = AuthorizedDomainsClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport="grpc",
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport="grpc",
     )
 
     # Mock the actual call within the gRPC stub, and fake the request.
@@ -705,7 +764,8 @@ async def test_list_authorized_domains_async(
     transport: str = "grpc_asyncio", request_type=appengine.ListAuthorizedDomainsRequest
 ):
     client = AuthorizedDomainsAsyncClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
@@ -740,13 +800,15 @@ async def test_list_authorized_domains_async_from_dict():
 
 
 def test_list_authorized_domains_field_headers():
-    client = AuthorizedDomainsClient(credentials=ga_credentials.AnonymousCredentials(),)
+    client = AuthorizedDomainsClient(
+        credentials=ga_credentials.AnonymousCredentials(),
+    )
 
     # Any value that is part of the HTTP/1.1 URI should be sent as
     # a field header. Set these to a non-empty value.
     request = appengine.ListAuthorizedDomainsRequest()
 
-    request.parent = "parent/value"
+    request.parent = "parent_value"
 
     # Mock the actual call within the gRPC stub, and fake the request.
     with mock.patch.object(
@@ -762,7 +824,10 @@ def test_list_authorized_domains_field_headers():
 
     # Establish that the field header was sent.
     _, _, kw = call.mock_calls[0]
-    assert ("x-goog-request-params", "parent=parent/value",) in kw["metadata"]
+    assert (
+        "x-goog-request-params",
+        "parent=parent_value",
+    ) in kw["metadata"]
 
 
 @pytest.mark.asyncio
@@ -775,7 +840,7 @@ async def test_list_authorized_domains_field_headers_async():
     # a field header. Set these to a non-empty value.
     request = appengine.ListAuthorizedDomainsRequest()
 
-    request.parent = "parent/value"
+    request.parent = "parent_value"
 
     # Mock the actual call within the gRPC stub, and fake the request.
     with mock.patch.object(
@@ -793,12 +858,16 @@ async def test_list_authorized_domains_field_headers_async():
 
     # Establish that the field header was sent.
     _, _, kw = call.mock_calls[0]
-    assert ("x-goog-request-params", "parent=parent/value",) in kw["metadata"]
+    assert (
+        "x-goog-request-params",
+        "parent=parent_value",
+    ) in kw["metadata"]
 
 
 def test_list_authorized_domains_pager(transport_name: str = "grpc"):
     client = AuthorizedDomainsClient(
-        credentials=ga_credentials.AnonymousCredentials, transport=transport_name,
+        credentials=ga_credentials.AnonymousCredentials,
+        transport=transport_name,
     )
 
     # Mock the actual call within the gRPC stub, and fake the request.
@@ -815,12 +884,21 @@ def test_list_authorized_domains_pager(transport_name: str = "grpc"):
                 ],
                 next_page_token="abc",
             ),
-            appengine.ListAuthorizedDomainsResponse(domains=[], next_page_token="def",),
             appengine.ListAuthorizedDomainsResponse(
-                domains=[domain.AuthorizedDomain(),], next_page_token="ghi",
+                domains=[],
+                next_page_token="def",
             ),
             appengine.ListAuthorizedDomainsResponse(
-                domains=[domain.AuthorizedDomain(), domain.AuthorizedDomain(),],
+                domains=[
+                    domain.AuthorizedDomain(),
+                ],
+                next_page_token="ghi",
+            ),
+            appengine.ListAuthorizedDomainsResponse(
+                domains=[
+                    domain.AuthorizedDomain(),
+                    domain.AuthorizedDomain(),
+                ],
             ),
             RuntimeError,
         )
@@ -833,14 +911,15 @@ def test_list_authorized_domains_pager(transport_name: str = "grpc"):
 
         assert pager._metadata == metadata
 
-        results = [i for i in pager]
+        results = list(pager)
         assert len(results) == 6
         assert all(isinstance(i, domain.AuthorizedDomain) for i in results)
 
 
 def test_list_authorized_domains_pages(transport_name: str = "grpc"):
     client = AuthorizedDomainsClient(
-        credentials=ga_credentials.AnonymousCredentials, transport=transport_name,
+        credentials=ga_credentials.AnonymousCredentials,
+        transport=transport_name,
     )
 
     # Mock the actual call within the gRPC stub, and fake the request.
@@ -857,12 +936,21 @@ def test_list_authorized_domains_pages(transport_name: str = "grpc"):
                 ],
                 next_page_token="abc",
             ),
-            appengine.ListAuthorizedDomainsResponse(domains=[], next_page_token="def",),
             appengine.ListAuthorizedDomainsResponse(
-                domains=[domain.AuthorizedDomain(),], next_page_token="ghi",
+                domains=[],
+                next_page_token="def",
             ),
             appengine.ListAuthorizedDomainsResponse(
-                domains=[domain.AuthorizedDomain(), domain.AuthorizedDomain(),],
+                domains=[
+                    domain.AuthorizedDomain(),
+                ],
+                next_page_token="ghi",
+            ),
+            appengine.ListAuthorizedDomainsResponse(
+                domains=[
+                    domain.AuthorizedDomain(),
+                    domain.AuthorizedDomain(),
+                ],
             ),
             RuntimeError,
         )
@@ -893,19 +981,30 @@ async def test_list_authorized_domains_async_pager():
                 ],
                 next_page_token="abc",
             ),
-            appengine.ListAuthorizedDomainsResponse(domains=[], next_page_token="def",),
             appengine.ListAuthorizedDomainsResponse(
-                domains=[domain.AuthorizedDomain(),], next_page_token="ghi",
+                domains=[],
+                next_page_token="def",
             ),
             appengine.ListAuthorizedDomainsResponse(
-                domains=[domain.AuthorizedDomain(), domain.AuthorizedDomain(),],
+                domains=[
+                    domain.AuthorizedDomain(),
+                ],
+                next_page_token="ghi",
+            ),
+            appengine.ListAuthorizedDomainsResponse(
+                domains=[
+                    domain.AuthorizedDomain(),
+                    domain.AuthorizedDomain(),
+                ],
             ),
             RuntimeError,
         )
-        async_pager = await client.list_authorized_domains(request={},)
+        async_pager = await client.list_authorized_domains(
+            request={},
+        )
         assert async_pager.next_page_token == "abc"
         responses = []
-        async for response in async_pager:
+        async for response in async_pager:  # pragma: no branch
             responses.append(response)
 
         assert len(responses) == 6
@@ -934,17 +1033,28 @@ async def test_list_authorized_domains_async_pages():
                 ],
                 next_page_token="abc",
             ),
-            appengine.ListAuthorizedDomainsResponse(domains=[], next_page_token="def",),
             appengine.ListAuthorizedDomainsResponse(
-                domains=[domain.AuthorizedDomain(),], next_page_token="ghi",
+                domains=[],
+                next_page_token="def",
             ),
             appengine.ListAuthorizedDomainsResponse(
-                domains=[domain.AuthorizedDomain(), domain.AuthorizedDomain(),],
+                domains=[
+                    domain.AuthorizedDomain(),
+                ],
+                next_page_token="ghi",
+            ),
+            appengine.ListAuthorizedDomainsResponse(
+                domains=[
+                    domain.AuthorizedDomain(),
+                    domain.AuthorizedDomain(),
+                ],
             ),
             RuntimeError,
         )
         pages = []
-        async for page_ in (await client.list_authorized_domains(request={})).pages:
+        async for page_ in (
+            await client.list_authorized_domains(request={})
+        ).pages:  # pragma: no branch
             pages.append(page_)
         for page_, token in zip(pages, ["abc", "def", "ghi", ""]):
             assert page_.raw_page.next_page_token == token
@@ -957,7 +1067,8 @@ def test_credentials_transport_error():
     )
     with pytest.raises(ValueError):
         client = AuthorizedDomainsClient(
-            credentials=ga_credentials.AnonymousCredentials(), transport=transport,
+            credentials=ga_credentials.AnonymousCredentials(),
+            transport=transport,
         )
 
     # It is an error to provide a credentials file and a transport instance.
@@ -977,7 +1088,10 @@ def test_credentials_transport_error():
     options = client_options.ClientOptions()
     options.api_key = "api_key"
     with pytest.raises(ValueError):
-        client = AuthorizedDomainsClient(client_options=options, transport=transport,)
+        client = AuthorizedDomainsClient(
+            client_options=options,
+            transport=transport,
+        )
 
     # It is an error to provide an api_key and a credential.
     options = mock.Mock()
@@ -993,7 +1107,8 @@ def test_credentials_transport_error():
     )
     with pytest.raises(ValueError):
         client = AuthorizedDomainsClient(
-            client_options={"scopes": ["1", "2"]}, transport=transport,
+            client_options={"scopes": ["1", "2"]},
+            transport=transport,
         )
 
 
@@ -1036,10 +1151,28 @@ def test_transport_adc(transport_class):
         adc.assert_called_once()
 
 
+@pytest.mark.parametrize(
+    "transport_name",
+    [
+        "grpc",
+    ],
+)
+def test_transport_kind(transport_name):
+    transport = AuthorizedDomainsClient.get_transport_class(transport_name)(
+        credentials=ga_credentials.AnonymousCredentials(),
+    )
+    assert transport.kind == transport_name
+
+
 def test_transport_grpc_default():
     # A client should use the gRPC transport by default.
-    client = AuthorizedDomainsClient(credentials=ga_credentials.AnonymousCredentials(),)
-    assert isinstance(client.transport, transports.AuthorizedDomainsGrpcTransport,)
+    client = AuthorizedDomainsClient(
+        credentials=ga_credentials.AnonymousCredentials(),
+    )
+    assert isinstance(
+        client.transport,
+        transports.AuthorizedDomainsGrpcTransport,
+    )
 
 
 def test_authorized_domains_base_transport_error():
@@ -1071,6 +1204,14 @@ def test_authorized_domains_base_transport():
     with pytest.raises(NotImplementedError):
         transport.close()
 
+    # Catch all for all remaining methods and properties
+    remainder = [
+        "kind",
+    ]
+    for r in remainder:
+        with pytest.raises(NotImplementedError):
+            getattr(transport, r)()
+
 
 def test_authorized_domains_base_transport_with_credentials_file():
     # Instantiate the base transport with a credentials file
@@ -1082,7 +1223,8 @@ def test_authorized_domains_base_transport_with_credentials_file():
         Transport.return_value = None
         load_creds.return_value = (ga_credentials.AnonymousCredentials(), None)
         transport = transports.AuthorizedDomainsTransport(
-            credentials_file="credentials.json", quota_project_id="octopus",
+            credentials_file="credentials.json",
+            quota_project_id="octopus",
         )
         load_creds.assert_called_once_with(
             "credentials.json",
@@ -1147,6 +1289,28 @@ def test_authorized_domains_transport_auth_adc(transport_class):
         )
 
 
+@pytest.mark.parametrize(
+    "transport_class",
+    [
+        transports.AuthorizedDomainsGrpcTransport,
+        transports.AuthorizedDomainsGrpcAsyncIOTransport,
+    ],
+)
+def test_authorized_domains_transport_auth_gdch_credentials(transport_class):
+    host = "https://language.com"
+    api_audience_tests = [None, "https://language2.com"]
+    api_audience_expect = [host, "https://language2.com"]
+    for t, e in zip(api_audience_tests, api_audience_expect):
+        with mock.patch.object(google.auth, "default", autospec=True) as adc:
+            gdch_mock = mock.MagicMock()
+            type(gdch_mock).with_gdch_audience = mock.PropertyMock(
+                return_value=gdch_mock
+            )
+            adc.return_value = (gdch_mock, None)
+            transport_class(host=host, api_audience=t)
+            gdch_mock.with_gdch_audience.assert_called_once_with(e)
+
+
 @pytest.mark.parametrize(
     "transport_class,grpc_helpers",
     [
@@ -1231,24 +1395,40 @@ def test_authorized_domains_grpc_transport_client_cert_source_for_mtls(transport
             )
 
 
-def test_authorized_domains_host_no_port():
+@pytest.mark.parametrize(
+    "transport_name",
+    [
+        "grpc",
+        "grpc_asyncio",
+    ],
+)
+def test_authorized_domains_host_no_port(transport_name):
     client = AuthorizedDomainsClient(
         credentials=ga_credentials.AnonymousCredentials(),
         client_options=client_options.ClientOptions(
             api_endpoint="appengine.googleapis.com"
         ),
+        transport=transport_name,
     )
-    assert client.transport._host == "appengine.googleapis.com:443"
+    assert client.transport._host == ("appengine.googleapis.com:443")
 
 
-def test_authorized_domains_host_with_port():
+@pytest.mark.parametrize(
+    "transport_name",
+    [
+        "grpc",
+        "grpc_asyncio",
+    ],
+)
+def test_authorized_domains_host_with_port(transport_name):
     client = AuthorizedDomainsClient(
         credentials=ga_credentials.AnonymousCredentials(),
         client_options=client_options.ClientOptions(
             api_endpoint="appengine.googleapis.com:8000"
         ),
+        transport=transport_name,
     )
-    assert client.transport._host == "appengine.googleapis.com:8000"
+    assert client.transport._host == ("appengine.googleapis.com:8000")
 
 
 def test_authorized_domains_grpc_transport_channel():
@@ -1256,7 +1436,8 @@ def test_authorized_domains_grpc_transport_channel():
 
     # Check that channel is used if provided.
     transport = transports.AuthorizedDomainsGrpcTransport(
-        host="squid.clam.whelk", channel=channel,
+        host="squid.clam.whelk",
+        channel=channel,
     )
     assert transport.grpc_channel == channel
     assert transport._host == "squid.clam.whelk:443"
@@ -1268,7 +1449,8 @@ def test_authorized_domains_grpc_asyncio_transport_channel():
 
     # Check that channel is used if provided.
     transport = transports.AuthorizedDomainsGrpcAsyncIOTransport(
-        host="squid.clam.whelk", channel=channel,
+        host="squid.clam.whelk",
+        channel=channel,
     )
     assert transport.grpc_channel == channel
     assert transport._host == "squid.clam.whelk:443"
@@ -1397,7 +1579,9 @@ def test_parse_common_billing_account_path():
 
 def test_common_folder_path():
     folder = "whelk"
-    expected = "folders/{folder}".format(folder=folder,)
+    expected = "folders/{folder}".format(
+        folder=folder,
+    )
     actual = AuthorizedDomainsClient.common_folder_path(folder)
     assert expected == actual
 
@@ -1415,7 +1599,9 @@ def test_parse_common_folder_path():
 
 def test_common_organization_path():
     organization = "oyster"
-    expected = "organizations/{organization}".format(organization=organization,)
+    expected = "organizations/{organization}".format(
+        organization=organization,
+    )
     actual = AuthorizedDomainsClient.common_organization_path(organization)
     assert expected == actual
 
@@ -1433,7 +1619,9 @@ def test_parse_common_organization_path():
 
 def test_common_project_path():
     project = "cuttlefish"
-    expected = "projects/{project}".format(project=project,)
+    expected = "projects/{project}".format(
+        project=project,
+    )
     actual = AuthorizedDomainsClient.common_project_path(project)
     assert expected == actual
 
@@ -1453,7 +1641,8 @@ def test_common_location_path():
     project = "winkle"
     location = "nautilus"
     expected = "projects/{project}/locations/{location}".format(
-        project=project, location=location,
+        project=project,
+        location=location,
     )
     actual = AuthorizedDomainsClient.common_location_path(project, location)
     assert expected == actual
@@ -1478,7 +1667,8 @@ def test_client_with_default_client_info():
         transports.AuthorizedDomainsTransport, "_prep_wrapped_messages"
     ) as prep:
         client = AuthorizedDomainsClient(
-            credentials=ga_credentials.AnonymousCredentials(), client_info=client_info,
+            credentials=ga_credentials.AnonymousCredentials(),
+            client_info=client_info,
         )
         prep.assert_called_once_with(client_info)
 
@@ -1487,7 +1677,8 @@ def test_client_with_default_client_info():
     ) as prep:
         transport_class = AuthorizedDomainsClient.get_transport_class()
         transport = transport_class(
-            credentials=ga_credentials.AnonymousCredentials(), client_info=client_info,
+            credentials=ga_credentials.AnonymousCredentials(),
+            client_info=client_info,
         )
         prep.assert_called_once_with(client_info)
 
@@ -1495,7 +1686,8 @@ def test_client_with_default_client_info():
 @pytest.mark.asyncio
 async def test_transport_close_async():
     client = AuthorizedDomainsAsyncClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport="grpc_asyncio",
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport="grpc_asyncio",
     )
     with mock.patch.object(
         type(getattr(client.transport, "grpc_channel")), "close"
@@ -1568,4 +1760,5 @@ def test_api_key_credentials(client_class, transport_class):
                 quota_project_id=None,
                 client_info=transports.base.DEFAULT_CLIENT_INFO,
                 always_use_jwt_access=True,
+                api_audience=None,
             )
